"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextProperties = void 0;
const util_1 = require("../util");
const FontVariant_1 = require("./FontVariant");
const LineMode_1 = require("./LineMode");
const LineStyle_1 = require("./LineStyle");
const LineType_1 = require("./LineType");
const LineWidth_1 = require("./LineWidth");
const TextTransformation_1 = require("./TextTransformation");
const Typeface_1 = require("./Typeface");
/**
 * This class represents the style of some text.
 *
 * @extends ITextProperties
 * @since 0.4.0
 * @private
 */
class TextProperties {
    /**
     * Constructor.
     *
     * @since 0.4.0
     */
    constructor() {
        this.fontSize = 12;
        this.fontVariant = FontVariant_1.FontVariant.Normal;
        this.transformation = TextTransformation_1.TextTransformation.None;
        this.typeface = Typeface_1.Typeface.Normal;
    }
    /** @inheritDoc */
    setBackgroundColor(color) {
        this.backgroundColor = color;
    }
    /** @inheritDoc */
    getBackgroundColor() {
        return this.backgroundColor;
    }
    /** @inheritDoc */
    setColor(color) {
        this.color = color;
    }
    /** @inheritDoc */
    getColor() {
        return this.color;
    }
    /** @inheritDoc */
    setFontName(name) {
        this.fontName = name;
    }
    /** @inheritDoc */
    getFontName() {
        return this.fontName;
    }
    /** @inheritDoc */
    setFontSize(size) {
        if ((0, util_1.isPositiveLength)(size)) {
            this.fontSize = size;
        }
    }
    /** @inheritDoc */
    getFontSize() {
        return this.fontSize;
    }
    /** @inheritDoc */
    setFontVariant(fontVariant) {
        this.fontVariant = fontVariant;
    }
    /** @inheritDoc */
    getFontVariant() {
        return this.fontVariant;
    }
    /** @inheritDoc */
    setOverline(color = 'font-color', width = LineWidth_1.LineWidth.Auto, style = LineStyle_1.LineStyle.Solid, type = LineType_1.LineType.Single, mode = LineMode_1.LineMode.Continuous) {
        if (typeof width !== 'number' || (0, util_1.isPositiveLength)(width)) {
            this.overline = {
                color,
                mode,
                style,
                type,
                width,
            };
        }
    }
    /** @inheritDoc */
    getOverline() {
        return this.overline;
    }
    /** @inheritDoc */
    removeOverline() {
        this.overline = undefined;
    }
    /** @inheritDoc */
    setTextTransformation(transformation) {
        this.transformation = transformation;
    }
    /** @inheritDoc */
    getTextTransformation() {
        return this.transformation;
    }
    /** @inheritDoc */
    setTypeface(typeface) {
        this.typeface = typeface;
    }
    /** @inheritDoc */
    getTypeface() {
        return this.typeface;
    }
    /** @inheritDoc */
    setUnderline(color = 'font-color', width = LineWidth_1.LineWidth.Auto, style = LineStyle_1.LineStyle.Solid, type = LineType_1.LineType.Single, mode = LineMode_1.LineMode.Continuous) {
        if (typeof width !== 'number' || (0, util_1.isPositiveLength)(width)) {
            this.underline = {
                color,
                mode,
                style,
                type,
                width,
            };
        }
    }
    /** @inheritDoc */
    getUnderline() {
        return this.underline;
    }
    /** @inheritDoc */
    removeUnderline() {
        this.underline = undefined;
    }
}
exports.TextProperties = TextProperties;
