import { Meta } from '../../api/meta';
/**
 * Transforms a {@link Meta} object into ODF conform XML
 *
 * @since 0.7.0
 */
export declare class MetaWriter {
    /**
     * Transforms the given {@link Meta} into Open Document Format.
     *
     * @param {Document} document The XML document
     * @param {Element} parent The parent node in the DOM
     * @param {Meta} meta The Meta to serialize
     * @since 0.7.0
     */
    write(document: Document, root: Element, meta: Meta): void;
    /**
     * Sets the `meta:creation-date` element to the date and time this class was constructed.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setCreationDateElement;
    /**
     * Sets the `dc:creator` element if creator is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setCreatorElement;
    /**
     * Sets the `dc:date` element if date is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setDateElement;
    /**
     * Sets the `dc:description` element if description is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setDescriptionElement;
    /**
     * Sets the `meta:editing-cycles` element to 1.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setEditingCyclesElement;
    /**
     * Sets the `meta:generator` element to the name and version of this library (`simple-odf/x.y.z`).
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setGeneratorElement;
    /**
     * Sets the `meta:initial-creator` element to the current user.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setInitialCreatorElement;
    /**
     * Sets the `meta:keyword` elements if any keyword is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setKeywordElements;
    /**
     * Sets the `dc:language` element if language is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setLanguageElement;
    /**
     * Sets the `meta:print-date` element if print date is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setPrintDateElement;
    /**
     * Sets the `meta:printed-by` element if printing name is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setPrintedByElement;
    /**
     * Sets the `dc:subject` element if subject is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setSubjectElement;
    /**
     * Sets the `dc:title` element if title is set.
     *
     * @param {Document} document The XML document
     * @param {Element} metaElement The meta element which will act as parent
     * @param {Meta} meta The metadata
     * @private
     */
    private setTitleElement;
}
