"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParagraphPropertiesVisitor = void 0;
const style_1 = require("../../api/style");
const OdfAttributeName_1 = require("../OdfAttributeName");
const OdfElementName_1 = require("../OdfElementName");
class ParagraphPropertiesVisitor {
    visit(paragraphProperties, document, parent) {
        const paragraphPropertiesElement = document.createElement(OdfElementName_1.OdfElementName.StyleParagraphProperties);
        parent.appendChild(paragraphPropertiesElement);
        const lineHeight = paragraphProperties.getLineHeight();
        switch (typeof lineHeight) {
            case 'number':
                paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatLineHeight, lineHeight + 'mm');
                break;
            case 'string':
                paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatLineHeight, lineHeight);
                break;
            default:
                break;
        }
        const lineHeightAtLeast = paragraphProperties.getLineHeightAtLeast();
        if (lineHeightAtLeast !== undefined) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StyleLineHeightAtLeast, lineHeightAtLeast + 'mm');
        }
        const lineSpacing = paragraphProperties.getLineSpacing();
        if (lineSpacing !== undefined) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StyleLineSpacing, lineSpacing + 'mm');
        }
        const horizontalAlignment = paragraphProperties.getHorizontalAlignment();
        if (horizontalAlignment !== style_1.HorizontalAlignment.Default) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatTextAlign, horizontalAlignment);
        }
        const horizontalAlignmentLastLine = paragraphProperties.getHorizontalAlignmentLastLine();
        if (horizontalAlignment === style_1.HorizontalAlignment.Justify &&
            horizontalAlignmentLastLine !== style_1.HorizontalAlignmentLastLine.Default) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatTextAlignLast, horizontalAlignmentLastLine);
        }
        if (paragraphProperties.getKeepTogether() === true) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatKeepTogether, 'always');
        }
        const widows = paragraphProperties.getWidows();
        if (widows !== undefined) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatWidows, widows.toString(10));
        }
        const orphans = paragraphProperties.getOrphans();
        if (orphans !== undefined) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatOrphans, orphans.toString(10));
        }
        const marginLeft = paragraphProperties.getMarginLeft();
        if (marginLeft !== 0) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatMarginLeft, marginLeft.toString(10) + 'mm');
        }
        const marginRight = paragraphProperties.getMarginRight();
        if (marginRight !== 0) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatMarginRight, marginRight.toString(10) + 'mm');
        }
        const textIndent = paragraphProperties.getTextIndent();
        if (textIndent !== 0) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatTextIndent, textIndent.toString(10) + 'mm');
        }
        const marginTop = paragraphProperties.getMarginTop();
        if (marginTop !== 0) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatMarginTop, marginTop.toString(10) + 'mm');
        }
        const marginBottom = paragraphProperties.getMarginBottom();
        if (marginBottom !== 0) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatMarginBottom, marginBottom.toString(10) + 'mm');
        }
        switch (paragraphProperties.getPageBreak()) {
            case style_1.PageBreak.Before:
                paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatBreakBefore, 'page');
                break;
            case style_1.PageBreak.After:
                paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatBreakAfter, 'page');
                break;
            default:
                break;
        }
        const backgroundColor = paragraphProperties.getBackgroundColor();
        if (backgroundColor !== undefined) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatBackgroundColor, backgroundColor.toHex());
        }
        const borderTop = paragraphProperties.getBorderTop();
        if (borderTop !== undefined &&
            borderTop.width > 0 &&
            borderTop.style !== style_1.BorderStyle.None) {
            const border = `${borderTop.width}mm ${borderTop.style} ${borderTop.color.toHex()}`;
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatBorderTop, border);
        }
        const borderBottom = paragraphProperties.getBorderBottom();
        if (borderBottom !== undefined &&
            borderBottom.width > 0 &&
            borderBottom.style !== style_1.BorderStyle.None) {
            const border = `${borderBottom.width}mm ${borderBottom.style} ${borderBottom.color.toHex()}`;
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatBorderBottom, border);
        }
        const borderLeft = paragraphProperties.getBorderLeft();
        if (borderLeft !== undefined &&
            borderLeft.width > 0 &&
            borderLeft.style !== style_1.BorderStyle.None) {
            const border = `${borderLeft.width}mm ${borderLeft.style} ${borderLeft.color.toHex()}`;
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatBorderLeft, border);
        }
        const borderRight = paragraphProperties.getBorderRight();
        if (borderRight !== undefined &&
            borderRight.width > 0 &&
            borderRight.style !== style_1.BorderStyle.None) {
            const border = `${borderRight.width}mm ${borderRight.style} ${borderRight.color.toHex()}`;
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatBorderRight, border);
        }
        const paddingLeft = paragraphProperties.getPaddingLeft();
        if (paddingLeft !== 0) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatPaddingLeft, paddingLeft.toString(10) + 'mm');
        }
        const paddingRight = paragraphProperties.getPaddingRight();
        if (paddingRight !== 0) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatPaddingRight, paddingRight.toString(10) + 'mm');
        }
        const paddingTop = paragraphProperties.getPaddingTop();
        if (paddingTop !== 0) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatPaddingTop, paddingTop.toString(10) + 'mm');
        }
        const paddingBottom = paragraphProperties.getPaddingBottom();
        if (paddingBottom !== 0) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatPaddingBottom, paddingBottom.toString(10) + 'mm');
        }
        if (paragraphProperties.getKeepWithNext() === true) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.FormatKeepWithNext, 'always');
        }
        if (paragraphProperties.getVerticalAlignment() !== style_1.VerticalAlignment.Default) {
            paragraphPropertiesElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StyleVerticalAlign, paragraphProperties.getVerticalAlignment());
        }
        const tabStops = paragraphProperties.getTabStops();
        if (tabStops.length === 0) {
            return paragraphPropertiesElement;
        }
        const tabStopsElement = document.createElement(OdfElementName_1.OdfElementName.StyleTabStops);
        paragraphPropertiesElement.appendChild(tabStopsElement);
        tabStops.forEach((tabStop) => {
            const tabStopElement = document.createElement(OdfElementName_1.OdfElementName.StyleTabStop);
            tabStopsElement.appendChild(tabStopElement);
            tabStopElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StylePosition, tabStop.getPosition() + 'mm');
            const type = tabStop.getType();
            const char = tabStop.getChar();
            if (type === style_1.TabStopType.Char && char !== undefined) {
                tabStopElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StyleType, type);
                tabStopElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StyleChar, char);
            }
            else if (type !== style_1.TabStopType.Left) {
                tabStopElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StyleType, type);
            }
            const leaderStyle = tabStop.getLeaderStyle();
            if (leaderStyle !== style_1.TabStopLeaderStyle.None) {
                tabStopElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StyleLeaderStyle, leaderStyle);
            }
            const leaderColor = tabStop.getLeaderColor();
            if (leaderColor !== undefined) {
                tabStopElement.setAttribute(OdfAttributeName_1.OdfAttributeName.StyleLeaderColor, leaderColor.toHex());
            }
        });
        return paragraphPropertiesElement;
    }
}
exports.ParagraphPropertiesVisitor = ParagraphPropertiesVisitor;
